@@ -1,7 +1,7 @@
 package Parse::Netstat::linux;
 
-our $DATE = '2014-12-02'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -118,7 +118,7 @@ Parse::Netstat::linux - Parse the output of Linux "netstat" command
 
 =head1 VERSION
 
-This document describes version 0.11 of Parse::Netstat::linux (from Perl distribution Parse-Netstat), released on 2014-12-02.
+This document describes version 0.12 of Parse::Netstat::linux (from Perl distribution Parse-Netstat), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -367,8 +367,6 @@ Whether to parse Unix socket connections.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -378,7 +376,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -386,7 +384,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Parse-Nets
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Parse-Netstat>.
+Source repository is at L<https://github.com/perlancar/perl-Parse-Netstat>.
 
 =head1 BUGS
 
@@ -402,7 +400,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
